# Einleitung [draft]

Smartphones enthalten immer mehr Sensoren, mit denen sie Daten aus ihrer Umwelt erfassen. Erst durch den Zugriff über Software werden diese Sensordaten zu nützlichen Features. So wird Beispielsweise das Display eingeschaltet, sobald man das Smartphone aus der Hosentasche holt oder ausgeschaltet, wenn man es sich ans Ohr hält. Ein großes Augenmerk erhält die Lokalisierung der Geräte. Hierdurch werden Anwendungen wie die Navigation ermöglicht. Bei der Distanzmessung geht es darum, die Strecke, die ein Gerät in Bewegung zurücklegt, zu erfassen. In dieser Arbeit soll untersucht werden, wie die Messung auf kleinen Skalen, im Zentimeterbereich, umgesetzt werden kann.

## Motivation und Ausgangslage [draft]

Der Fokus dieser Arbeit liegt auf der Umsetzung der Distanzmessung mittels Bluetooth unter Verwendung des \ac{rssi}. Diese Lösung wird häufig in der Indoor-Navigation angewandt, da sie sowohl kostengünstig als auch weit verbreitet ist. Hierbei findet die Lokalisierung der Geräte zum Beispiel durch Triangulation mittels Referenzpunkten statt. Diese Reverenzpunkte werden als Bluetooth-Beacons bezeichnet. Sie können sowohl weitere Smartphones, als auch dedizierte Hardware sein. Bei der Indoor-Navigation sind diese Referenzpunkte mehrere Meter auseinander, was zu einer geringen Signalstärke am Empfänger und somit zu größeren Auswirkungen von Störeinflüssen führt. Bei der Messung von kleinen Skalen können die Bluetooth-Beacons in einem engeren Raster angeordnet werden. 

## Zielsetzung [draft]

Das Ziel der Arbeit ist es, die Genauigkeit einer Distanzmessung auf einem eingeschränkten Bereich von rund \SI{2}{\meter} zu erhöhen. Das gewählte Setup soll dabei möglichst einfach umsetzbar sein.
Mithilfe einer Beispielimplementierung soll die Genauigkeit dieses Setups untersucht werden. Zur weiteren Verbesserung der Genauigkeit sollen verschiedene Filtermöglichkeiten implementiert werden. Mit einer genauen Distanzmessung lassen sich beispielsweise neue Experimente mit dem Smartphone umsetzen.

---

Im Smartphone befinden sich mehrere Sensoren, die zur Lokalisierung des Geräts eingesetzt werden können. Da sich die Experimente mit phyphox&reg; meist im Innenraum abspielen, wird GPS für diesen Einsatzzweck nicht betrachtet. Mithilfe von WLAN, Bluetooth, NFC, Magnetometer, Gyroskop, Accelerometer, Kamera und Ultraschall bleiben jedoch viele weitere Möglichkeiten zur Lokalisierung bestehen [@maghdid_comprehensive_2021].

Bei der Smartphone-Anwendung phyphox&reg; handelt es sich um eine Open-Source-Anwendung, mit deren Hilfe Experimente mit dem Smartphone durchgeführt werden können. Hierzu greift sie auf die im Gerät verbauten Sensoren zurück. So lassen sich zum Beispiel mit dem Luftdrucksensor die im Fahrstuhl zurückgelegten Stockwerke ermitteln und anzeigen, oder die Länge eines Pendels, an dem das Smartphone hängt, durch die Pendelfrequenz berechnen. Anwender können mithilfe von XML-Dateien die Anwendung um eigene Experimente erweitern. Hierdurch wird phyphox&reg; gerade für Schulen interessant, da es Schülern die Möglichkeit bietet, die Theorie in der Praxis zu erleben. Aktuell fehlt jedoch eine Möglichkeit zur Distanzmessung. Durch diese könnten Experimente wie die Errechnung der Beschleunigung aus der zurückgelegten Wegstrecke und der Zeit durchgeführt werden.

Um eine genaue Distanzmessung durchführen zu können muss die Punktuelle Lokalisation eines Gerätes möglich genau sein. 

Die Distanz beschreibt die Länge einer, durch eine dynamische Bewegung zurückgelegten Strecke. Die Entfernung hingegen beschreibt den Abstand zwischen zwei Punkten im Raum. Die Lokalisierung bezeichnet die Position in einem 2D oder 3D Raum.

---

## Aufbau der Arbeit

# Technische Grundlagen

In diesem Artikel werden die technischen Grundlagen erörtert und eine abschließende Bewertung durchgeführt. Dabei werden die Grundlagen zunächst allgemein betrachtet und in weiteren Kapiteln vertieft.

## Distanzmessung

Die Distanzmessung beschreibt im Rahmen dieser Arbeit die Messung der Länge einer zurückgelegten Strecke. Dabei bezeichnet die Strecke den Weg zwischen Start- und Zielpunkt. Die digitale Erfassung einer Strecke basiert auf der Erfassung einzelner Wegpunkte [@Lerch_2006_BOOK, vgl. S. 7-8]. Da zwischen den Wegpunkten keine Informationen vorliegen, wird dieser Zwischenraum als Gerade angenommen. Wie Abbildung \ref{fig:wegpunktcount} verdeutlicht, wird die Streckenabbildung durch die Anzahl an aufgezeichneten Wegpunkten verbessert. Im linken Teil der Abbildung sind nur drei Messpunkte erfasst worden, der ermittelte Weg ergibt nahezu eine Gerade und entspricht nicht dem realen Weg. Im rechten Teil sind 8, gleichmäßig verteilte Messpunkte, der aufgezeichnete Weg entspricht fast dem realen Weg.

![Auswirkung der Erfassungshäufigkeit von Wegpunkten. \label{fig:wegpunktcount}](../static/Wegpunkte.pdf)

## Lokalisierung

Zur Bestimmung der einzelnen Wegpunkte ist eine Lokalisierung des Messobjektes erforderlich. Hierbei wird die Position des Objekts im Raum bestimmt. Der Raum kann dabei eindimensional oder mehrdimensional sein [@Strang_2008_BOOK]. Die folgenden Kapitel erörtern verschiedene Verfahren zur Lokalisierung, bei denen die Position des oder der Sender bekannt ist und die Position des Empfängers ermittelt werden soll.

### Cell-ID

Zu den einfachsten Methoden der Lokalisierung gehört das \ac{cellid}-Verfahren. Dabei haben alle Sender einen eindeutig zugeordneten \ac{id}. Diese \ac{id} wird vom Sender mit ausgestrahlt. Der Empfangsbereich, in dem ein Sender empfangen werden kann, nennt sich Zelle (engl. Cell). Ein Empfänger, der das Signal empfängt, kann dieses durch die \ac{id} eindeutig einem Sender und dessen Zelle zuordnen [@Strang_2008_BOOK]. Dabei ist die Genauigkeit des Verfahrens im wesentlichen von der Reichweite, also der Größe der jeweiligen Zelle, des Senders abhängig. 

Die Lokalisierung kann verbessert werden, wenn sich mehrere Sendezellen überlappen. Abbildung \ref{fig:cellid} rechts zeigt, das in diesem Fall die Position des Empfängers auf die Schnittmenge der Sendezellen begrenzt wird, die vom Empfänger empfangen werden. Der rötlich eingefärbte Bereich kennzeichnet das Areal in dem sich der Empfänger befinden kann. Die rote Begrenzung ist die Sendereichweite des Senders.

![Positionsbestimmung durch überschneidende Zellen. \label{fig:cellid}](../static/cellid.pdf)

### Fingerprinting

Das Fingerprinting ist ein Ansatz, der sich die Mehrwegausbreitung (mehr dazu unter Abschnitt \ref{fehlerkorrekturen}) von Funksignalen zu Nutze macht. Hierbei wird für jeden Empfangsort ein charakteristisches Muster (Fingerabdruck, engl. Fingerprint) aufgezeichnet [@Strang_2008_BOOK]. Dabei gliedert sich dieses Verfahren in zwei Phasen:

1. Die Offline-Phase: Hierbei werden passende ortsabhängige Parameter bestimmt, durch die eine eindeutige Identifikation eines Ortes möglich ist. Diese Parameter werden für jeden Ort gemessen und in einer Datenbank mit der Ortsinformation verknüpft gespeichert. Die ortsabhängigen Parameter hängen stark von der Umgebung ab. Bei einer Umgebungsänderung müssen diese Parameter aktualisiert werden. 
2. Die Online-Phase: Dabei misst der Empfänger den Fingerprint, also den Parameter zur Identifikation, und gleicht diesen mit der Datenbank ab. Dazu werden Mustererkennungsalgorithmen benötigt, welche aus der Datenbank den wahrscheinlichsten Fingerprint ermitteln und damit den wahrscheinlichsten Ort herausgeben.


### Triangulation

Die Triangulation basiert auf der Ermittlung des Einfallswinkels der eingehenden Signale. Dieses Verfahren wird auch \ac{aoa} genannt. Die Messung des Einfallswinkels ist mit gerichteten Antennenarrays oder Laufzeitmessungen zwischen mehreren Antennen möglich. Für den einfachen Fall einer Messung kann keine Entfernungsinformation gewonnen werden. Erst mehrere Messungen führen zu einem linearen Gleichungssystem, dessen Lösung die Position des Empfängers bestimmt [@Strang_2008_BOOK].

![2D Positionierung über \acl{aoa}. \label{fig:aoa}](../static/aoaPositioning.pdf)

### Trilateration

Bei der Lateration handelt es um ein Methode zur Positionsbestimmung bei der die Entfernung zwischen Sender und Empfänger ermittelt wird. Durch die Entfernung zwischen Sender und Empfänger entsteht im zweidimensionalen Bereich ein Kreis um den Sender. Der Empfänger befindet sich dann auf einem Punkt dieser Kreisbahn [@Strang_2008_BOOK]. Um eine eindeutige Position zu ermitteln sind mindestens drei Sender notwendig, weswegen diese Methode auch Trilateration genannt wird. Abbildung \ref{fig:lateration} zeigt das Verfahren: Die Position des Empfängers wurde zur besseren Darstellung nur eingekreist, er befindet sich auf dem Schnittpunkt der im inneren des gestrichelten schwarzen Kreis zu erkennen ist. Der Abstand zwischen Sender und Empfänger $r$ entspricht dem Radius des Kreises um den Sender. Der Empfänger befindet sich auf einem unbestimmten Punkt der Kreislinie. Wird nun ein weiterer Sender hinzugefügt, so definieren die jeweiligen Schnittpunkte der Kreise die mögliche Position des Empfängers. Bei drei Sendern gibt es im optimalen Fall nur einen Schnittpunkt bei dem alle drei Kreislinien aufeinander treffen. 

![2D-Positionierung mit der Trilateration \label{fig:lateration}](../static/lateration.pdf)

Formel \ref{eq:lgsTrilateration} zeigt das allgemeine lineare Gleichungssystem zur Berechnung der Position bei der Trilateration [@Noertjahyana_2017]. Dabei beschreibt $x_i$ und $y_i$ die Position der Sender $i=1,2,3$ und $r_i$ den gemessenen Abstand zwischen Sender $i$ und Empfänger.

\begin{equation}\label{eq:lgsTrilateration}
\begin{aligned}
  r_1^2= (x-x_1)^2 + (y-y_1)^2 \\
  r_2^2= (x-x_2)^2 + (y-y_2)^2 \\
  r_3^2= (x-x_3)^2 + (y-y_3)^2
\end{aligned}
\end{equation}

Im weiteren werden die Verfahren zur Ermittlung der Entfernung zwischen Sender und Empfänger vorgestellt.

#### Laufzeitmessung {-}

Die Laufzeitmessung, besser bekannt unter dem englischen Begriff \ac{toa}, beruht auf der Messung der absoluten Signallaufzeit $t = t_i - t_0$ von einem Sender zum Empfänger. Dabei beschreibt $t_i$ die Sendezeit und $t_0$ den Empfangszeitpunkt des Signals. Zur Berechnung der Distanz $r$ wird die Lichtgeschwindigkeit $c$ mit der Laufzeit des Signals multipliziert: $r = c \cdot t$. Für diese Messung ist eine sehr genaue und zwischen Sender und Empfänger synchronisierte Zeiterfassung notwendig [@Strang_2008_BOOK]. 

#### Laufzeitdifferenzmessung {-}

Bei der Laufzeitdifferenzmessung, auch bekannt als \ac{tdoa}, wird die Differenz der Signallaufzeit zweier Sender am Empfänger gemessen. Der Vorteil gegenüber dem \ac{toa}-Verfahren liegt darin, dass keine Zeitsynchronizität zwischen dem Sender und Empfänger hergestellt werden muss. Die Laufzeitdifferenzen zwischen den Signalen zweier Sender entspricht damit einer Differenz der Distanz vom Empfänger zu den beiden Sendern [@Strang_2008_BOOK].

#### Signalstärkemessung {-}

Die Messung der Signalstärke, auch bekannt als \ac{rss} ist ein gängiges Verfahren bei der Lokalisierung mithilfe von Funksystemen [@Chen_2019; @Davidson_2017a; @Ye_2019]. Hierbei wird die Empfangsleistung und damit die Dämpfung des Signals am Empfänger gemessen. Dabei hängt die Signaldämpfung unter anderem von der Distanz zwischen Sender und Empfänger ab. Zur Berechnung der Entfernung ist die Kenntnis über den mathematischen Zusammenhang zwischen Entfernung und Signaldämpfung notwendig. Diese Ausbreitungsmodelle sind für viele Szenarien bekannt [@Strang_2008_BOOK].

### Fazit

Im Folgenden sollen die eingangs erwähnten Verfahren zur Lokalisierung hinsichtlich der Fragestellung betrachtet werden. Dabei liegt ein besonderes Augenmerk auf der möglichen Ortsauflösung und dem Aufwand, mit dem das Verfahren umgesetzt werden kann.

Das \ac{cellid}-Verfahren hat eine sehr geringe Ortsauflösung. Auch mit einer hohen Anzahl an Sendern bleibt die ermittelte Position nur ein diffuses Areal anstelle einer punktgenauen Lokalisierung. Der Aufwand der Umsetzung hingegen ist als eher gering einzuschätzen.

Beim Fingerprinting-Verfahren ist die Ortsauflösung unter anderem vom betriebenen Aufwand bei der Einrichtung abhängig. Auch die gewählten Parameter zum Erstellen des Fingerabdrucks und die Beständigkeit der Umgebung haben großen Einfluss auf die Ortsauflösung. Daher muss die Einrichtung bei Veränderungen an der Umgebung erneut durchgeführt werden, was den Aufwand für diese Methode stark erhöht.

Das \acl{aoa}-Verfahren lässt sich nur umsetzen, wenn das Gerät die benötigte Hardware zur Ermittlung des Eintrittswinkel mitbringt. Die Ortsauflösung ist dann jedoch nur von den Messfehlern abhängig und kann somit zunächst als sehr hoch eingestuft werden. Der Aufwand ist jedoch, passende Hardware vorausgesetzt, relativ gering.

Für die Trilateration stehen mehrere Verfahren zur Auswahl. Diese unterscheiden sich hauptsächlich im Aufwand. Die Ortsauflösung ist, wie schon beim \ac{aoa}-Verfahren, abhängig von den Messfehlern der eingesetzten Verfahren. Dabei wird beim \ac{rss}-Verfahren eine etwas geringere Ortsauflösung angenommen, da die Entfernung aufgrund der Signalstärke nicht nur durch Umwelteinflüsse, sondern auch durch das verwendete Modell beeinflusst wird. Der Aufwand für \ac{toa} und \ac{tdoa} wird mit sehr hoch angenommen, da eine genaue Zeitmessung spezielle Hardware voraussetzt. Diese Hardware ist in Smartphones nicht verbaut.

| Verfahren | mögliche Ortsauflösung | Aufwand |
| ------- | ------------- | ------- |
| \ac{cellid} | sehr gering | gering |
| Fingerprinting | stark schwankend | sehr hoch |
| \acl{aoa} | sehr hoch | gering |
| \acl{toa} | sehr hoch | sehr hoch |
| \acl{tdoa} | sehr hoch | sehr hoch |
| \acl{rss} | hoch | gering |
: Übersicht und Bewertung der Verfahren zur Lokalisierung. \label{tab:location}

## Smartphonesensoren

Aktuelle Smartphones besitzen eine Vielzahl von Sensoren, um mit ihrer Umwelt zu interagieren. Viele der Sensoren lassen sich alleine oder in Kombination zur Entfernungsmessung oder Distanzmessung einsetzen [@Subbu_2013; @Chen_2019; @Li_2012; @SosaSesma_2016]. 

Die Entfernung zu einem Referenzpunkt wie einer Wand, lässt sich zum Beispiel durch den Einsatz eines Sonars messen. Für die Umsetzung kommen das Mikrofon und der Lautsprecher des Smartphones in Frage [@Graham_2015]. In dieser Arbeit geht es jedoch um einen flexibleren Einsatzbereich, bei dem eine Lokalisierung zwingend erforderlich ist.

Zu den bekanntesten Sensoren zur Lokalisierung gehört das \ac{gps}. Hierbei wird mit Hilfe von Satelliten die Position des Smartphones ermittelt. Dies ermöglicht die Ortung außerhalb von Gebäuden mit einer Genauigkeit von wenigen Metern [@Bajaj_2002a]. Da die Messungen jedoch nicht auf den Außenbereich beschränkt sein sollen, wird \ac{gps} nicht näher betrachtet.

Die Innenraum-Lokalisierung und Navigation ist ein Forschungsfeld mit großem Interesse. Viele Arbeiten basieren auf dem vom \ac{ieee} festgelegten Standard IEEE 802.11, besser bekannt als \ac{wifi} [@Chen_2019]. Für den Einsatz von \ac{wifi} zur Lokalisierung muss zunächst eine Karte (siehe Kapitel \ref{fingerprinting}) mit der Funkstärkenverteilung erstellt werden [@Davidson_2017a]. Dies bedeutet einen hohen zeitlichen Aufwand bei der Einrichtung und eine geringe Flexibilität im Einsatz.

Ein weiterer Sensor, der zur Lokalisierung in Innenräumen häufig betrachtet wird, ist Bluetooth. Dieser ist weit verbreitet und kostengünstiger als \ac{wifi} [@Ye_2019]. Des Weiteren wurde mit \ac{ble} ein Standard entwickelt, der sehr stromsparend ist. Im weiteren Verlauf der Arbeit soll Bluetooth näher betrachtet werden.

## Bluetooth

Bei Bluetooth handelt es sich um einen, durch die \ac{sig} entwickelten, Industriestandard zur Datenübertragung über kurze Distanzen per Funktechnik. Bluetooth arbeitet im lizenzfreiem \ac{ism} von \SIrange{2,402}{2,480}{\giga\Hz}, dadurch darf es weltweit zulassungsfrei betrieben werden. Mit Bluetooth 4.0 wurde \acl{ble} eingeführt. Dieses ist nicht abwärtskompatibel, bietet jedoch einige nützliche Besonderheiten: Ein reduzierter Stromverbrauch und die kurze Aufbauzeit einer Übertragung sind die wesentlichen Vorteile. 

\acl{ble} befindet sich im gleichen \ac{ism} wie das klassische Bluetooth. Es teilt den Frequenzbereich jedoch nicht in 79 Kanälen von \SI{1}{\mega\Hz}, sondern in 40 Kanälen von je \SI{2}{\mega\Hz} auf.

### BLE und Entfernungsmessung

- Mögliche Verfahren mit dem Smartphone

### RSSI

- RSSI - Verfahren
- Formel für das RSSI BLE Scenario

## Messkette

## Fehler

### Systematische Fehler

### Zufällige Fehler

### Fehlerkorrekturen

### Filter

Filterverfahren in Tabelle, Erklärung was Filter machen.
Nicht alle müssen angewandt werden.

## Bewertung

## Beschreibung der eigenen Idee/ Innovation

# Implementierung

## Hardware

## Software

### Android App

### Bluetooth Beacon

# Testaufbau

In diesem Kapitel wird der Versuchsaufbau beschrieben. Dieser orientiert sich an den Anforderungen aus dem vorherigen Kapitel. Im Fokus steht hierbei die Umsetzung eines einfach umzusetzenden Versuchsaufbau, der eine möglichst genaue Messung ermöglicht.

## Anordnung der Beacon

Die Bluetooth-Beacon werden in einem gleichseitigen Dreieck mit einer Seitenlänge von \SI{1}{\meter} auf einer ebenen Fläche angeordnet (Abbildung \ref{fig:versuchsaufbau}). Hierdurch empfängt jeder Beacon von seinen Nachbarn den RSSI Wert auf \SI{1}{\meter} Entfernung und kann diesen zur Kalibrierung an das Smartphone übermitteln. Dieser Versuchsaufbau ermöglicht es, das System um weitere Beacon zu erweitern. Auch ließe sich hierdurch eine Dreieckspyramide mit 6 gleichlangen Kanten aufbauen. Dadurch ließe sich die die Messung auf die 3. Dimension erweitern.

## Messpunkte

Der Versuchsaufbau wird, wie in Abbildung \ref{fig:zones} dargestellt, in drei Zonen eingeteilt. Die ersten beiden Zonen ergeben sich aus der Geometrie des Versuchsaufbaus. Zone 1 hat einen Radius von \SI{0.289}{\meter} und wird durch das gleichseitige Dreieck begrenzt. In dieser Zone ist kein Beacon weiter als \SI{0.866}{\meter} vom Smartphone entfernt. Zone 2 misst einen Radius von \SI{0.577}{\meter} und schließt das Dreieck ein. Die maximale Distanz zu einem Beacon beträgt \SI{1.154}{\meter}. 

Zone 3 ergibt sich aus dem, im Artikel [@Cho_2015a] beschriebenen maximal sinnvollen Messabstand von \SI{1.5}{\meter}. Der am weitesten entfernte Punkt von einem Beacon ist somit \SI{1.5}{\meter}. Daraus ergibt sich ein Radius von \SI{1.067}{\meter} um das Zentrum.

Zu den Messpunkten in und am Rand der Zonen kommt ein spezieller Messpunkt. Dieser befindet sich auf einer Seite des Dreiecks und liegt somit genau zwischen zwei Beacon. Er wurde gewählt, um den Einfluss des Smartphones auf die Funkstrecke der Beacon zu untersuchen.

![Aufteilung des Versuchsaufbaus in Zonen und Messpunkte. \label{fig:zones}](../static/Zonen_und_Messpunkte.pdf)

# Messauswertung

# Ergebnisse

# Zusammenfassung und Ausblick

## Zusammenfassung und Fazit

## Ausblick

# Literaturverzeichnis